Skip to content
KitploitKITPLOIT
HerramientasExploitsBlog
Log in
Enviar
HerramientasExploitsBlog
Enviar

¡Herramientas de Hacking, PenTest y Ciberseguridad para tu Arsenal de Seguridad!

Kitploit es un directorio de herramientas de hacking, ciberseguridad y pentesting. Descubre las últimas actualizaciones de proyectos para encontrar vulnerabilidades, analizar sistemas, automatizar pruebas y fortalecer tu seguridad.

FeedsContactoPrivacidad© 2026 Kitploit

Directorio de Herramientas

Categorías

Ver todas las categorías
Loading categories
aztarna — aztarna, una herramienta de footprinting para robots. | Kitploit
Herramientas/GitHubGitHub/aliasrobotics/aztarna
Seguridad de Sistemas EmbebidosOSINT (Inteligencia de Fuentes Abiertas)ReconocimientoSeguridad IoTMapeo de RedesAnálisis de VulnerabilidadesSeguridad SCADA/ICSRecopilación de InformaciónPruebas de PenetraciónSeguridad de Hardware e IoTArchived
923143hace 3 mesesRevisado por Kitploit

Más Populares

Ver todos →

Descubre las herramientas más usadas por nuestra comunidad.

Explora todas las herramientas

Explora nuestra colección de herramientas

Ver todas las herramientas →
Compartir
GitHub
aliasrobotics/aztarna

aztarna

aztarna, una herramienta de footprinting para robots.

Ver RepositorioSitio web

Este repositorio ha sido archivado y ya no se mantiene. Consulte alurity para futuros avances en footprinting y fingerprinting de robots.

aztarna

Este repositorio contiene aztarna de Alias Robotics, una herramienta de footprinting para robots.

Alias Robotics apoya a los fabricantes originales de robots en la evaluación de su seguridad y mejora de la calidad de su software. De ninguna manera alentamos o promovemos la manipulación no autorizada de sistemas robóticos en funcionamiento. Esto puede causar daños humanos graves y daños materiales.

PyPI version Documentation Status Article

Edición de lectura HTML: Aztarna, a footprinting tool for robots

Para ROS

  • Una lista de los nodos ROS presentes en el sistema (Publicadores y Suscriptores)
  • Para cada nodo, los temas publicados y suscritos, incluyendo el tipo de tema
  • Para cada nodo, los servicios ROS que ofrece cada nodo
  • Una lista de todos los parámetros ROS presentes en el Servidor de Parámetros
  • Una lista de las comunicaciones activas que se ejecutan en el sistema. Una sola comunicación incluye los nodos publicador/suscriptor involucrados y los temas

Para SROS

  • Determinar si el sistema es un maestro SROS.
  • Detectar si se está utilizando la configuración de demostración.
  • Una lista de los nodos encontrados en el sistema. (Modo extendido)
  • Una lista de políticas de permitir/denegar para cada nodo.
    • Temas publicables.
    • Temas suscribibles.
    • Servicios ejecutables.
    • Parámetros legibles.

Para ROS2 (Financiado bajo el proyecto ROSIN)

  • Una lista de los nodos ROS2 presentes en cada dominio de comunicación.
  • Una lista de los temas descubiertos en cada dominio de comunicación.
  • Una lista de los servicios descubiertos en cada dominio de comunicación.
  • Para cada nodo, la relación de temas publicados y suscritos.
  • Para cada nodo, los servicios proporcionados por ese nodo.

Para routers industriales

  • Detección de routers industriales eWON, Moxa, Sierra Wireless y Westermo.
  • Comprobación de credenciales predeterminadas para los routers encontrados.

Para paquetes ROS Industrial (Financiado bajo el proyecto ROSIN)

  • Detección de hosts ROS Industrial.
  • Fabricantes:
    • ABB
    • Fanuc
    • Kuka

Instalación

Para producción

Directamente desde PyPi

pip3 install aztarna

o desde el repositorio:

pip3 install .

Para desarrollo

pip3 install -e .

o

python3 setup.py develop

Se requiere Python 3.6 y el paquete setuptools para la instalación. Se recomienda Python 3.7.

Módulo ROS2

Para el uso del módulo de footprinting de ROS2 se requiere una instalación de ROS2. Ejecute el script setup.bash antes de lanzarlo.

Instalar con Docker

docker build -t aztarna_docker .

Uso del código:

usage: aztarna [-h] -t TYPE [-a ADDRESS] [-p PORTS] [-i INPUT_FILE]
               [-o OUT_FILE] [-e] [-r RATE] [-d DOMAIN] [--daemon] [--hidden]
               [--shodan] [--api-key API_KEY] [--passive PASSIVE]

Aztarna

optional arguments:
  -h, --help            show this help message and exit
  -t TYPE, --type TYPE  <ROS/ros/SROS/sros/ROS2/ros2/IROUTERS/irouters> Escanea hosts ROS, SROS, ROS2 o routers industriales
  -a ADDRESS, --address ADDRESS
                        Dirección única o rango de red a escanear.
  -p PORTS, --ports PORTS
                        Puertos a escanear (formato: 13311 o 11111-11155 o 1,2,3,4)
  -i INPUT_FILE, --input_file INPUT_FILE
                        Archivo de entrada con direcciones para usar en el escaneo
  -o OUT_FILE, --out_file OUT_FILE
                        Archivo de salida para los resultados
  -e, --extended        Escaneo extendido de los hosts
  -r RATE, --rate RATE  Máximo de conexiones de red simultáneas
  -d DOMAIN, --domain DOMAIN
                        ID de dominio de ROS 2 (variable de entorno ROS_DOMAIN_ID). Solo aplica a ROS 2.
  --daemon              Usar el demonio rclpy (proveniente de ros2cli).
  --hidden              Muestra nodos ROS 2 ocultos. Por defecto filtra _ros2cli*
  --shodan              Usar shodan para los tipos de escaneo que lo soportan.
  --api-key API_KEY     Clave API de Shodan
  --passive PASSIVE     Búsqueda pasiva para ROS2

Ejecutar el código (ejemplo con archivo de entrada):

aztarna -t ROS -p 11311 -i ros_scan_s20.csv

Ejecutar el código con Docker (ejemplo con archivo de entrada):

docker run -v <host_path>:/root -it aztarna_docker -t ROS -p 11311 -i <input_file>

Ejecutar el código (ejemplo con una sola dirección IP):

aztarna -t ROS -p 11311 -a 115.129.241.241

Ejecutar el código (ejemplo con subred):

aztarna -t ROS -p 11311 -a 115.129.241.0/24

Ejecutar el código (ejemplo con una sola dirección IP y rango de puertos):

aztarna -t ROS -p 11311-11500 -a 115.129.241.241

Ejecutar el código (ejemplo con una sola dirección IP y lista de puertos):

aztarna -t ROS -p 11311,11312,11313 -a 115.129.241.241

Ejecutar el código con ROS 2 (ejemplo explorando todos los rangos, 0-231)

aztarna -t ROS2

Ejecutar el código con ROS 2 con ROS_DOMAIN_ID=15

aztarna -t ROS2 -d 15

Ejecutar el código con ROS 2 usando el demonio rclpy ros2cli y con ROS_DOMAIN_ID=0 mostrando nodos ocultos

aztarna -t ros2 -d 0 --daemon --hidden

Ejecutar el código con ROS 2 usando modo pasivo para buscar los hosts. Si establece 'any' como argumento, buscará en todas las interfaces de su sistema:

aztarna -t ros2 --passive any

Ejecutar el código (ejemplo canalizando directamente desde zmap):

zmap -p 11311 0.0.0.0/0 -q | aztarna -t SROS -p 11311

Ejecutar el código (ejemplo de búsqueda de routers industriales en shodan)

aztarna -t IROUTERS --shodan --api-key <yourshodanapikey>

Ejecutar el código (ejemplo de búsqueda de routers industriales en shodan, canalizando a archivo)

aztarna -t IROUTERS --shodan --api-key <yourshodanapikey> -o routers.csv

Cite nuestro trabajo

Si está utilizando nuestro trabajo para su investigación, por favor cítenos como:

@ARTICLE{2018arXiv181209490V,
  author = {{Vilches}, V{\'\i}ctor Mayoral and {Mendia}, Gorka Olalde and
  {Baskaran}, Xabier Perez and {Cordero}, Alejandro Hern{\'a}ndez
  and {Juan}, Lander Usategui San and {Gil-Uriarte}, Endika and
  {de Urabain}, Odei Olalde Saez and {Kirschgens}, Laura Alzola},
  title = "{Aztarna, a footprinting tool for robots}",
  journal = {arXiv e-prints},
  keywords = {Computer Science - Cryptography and Security, Computer Science - Robotics},
  year = 2018,
  month = Dec,
  eid = {arXiv:1812.09490},
  pages = {arXiv:1812.09490},
  archivePrefix = {arXiv},
  eprint = {1812.09490},
  primaryClass = {cs.CR},
  adsurl = {https://ui.adsabs.harvard.edu/\#abs/2018arXiv181209490V},
  adsnote = {Provided by the SAO/NASA Astrophysics Data System}
}

rosin_logo
Descargar herramienta